package App::bcrypt;
use utf8;
use v5.30;

our $VERSION = '1.002';

=encoding utf8

=head1 NAME

App::bcrypt - A command-line tool to deal with bcrypt password hashing

=head1 SYNOPSIS

	use App::bcrypt;

=head1 DESCRIPTION

This module is a placeholder to reserve the namespace, and you don't
need it for the program its distribution provides. The Perl module
distribution is there to install the prerequisites.

=head1 TO DO


=head1 SEE ALSO

=over 4

=item * Crypt::Bcrypt (which this program uses)

=item * Mojolicious::Plugin::Bcrypt

=item * Mojolicious::Command::bcrypt

=item * https://github.com/shoenig/bcrypt-tool, a Golang tool

=back

=head1 SOURCE AVAILABILITY

This source is in Github:

	http://github.com/briandfoy/app-bcrypt

=head1 AUTHOR

brian d foy, C<< <briandfoy@pobox.com> >>

=head1 COPYRIGHT AND LICENSE

Copyright © 2023, brian d foy, All Rights Reserved.

You may redistribute this under the terms of the Artistic License 2.0.

=cut

1;
